@@ -6,8 +6,7 @@ OUTPUT_DIR_LOCATION = "the location of the output directory"
 LOGIN_PROMPT_DOMAIN = "Please enter your cnvrg domain"
 LOGIN_PROMPT_EMAIL = "Please enter your email"
 LOGIN_PROMPT_PASSWORD = "Please enter your password"
-LOGIN_HELP_AUTH_TOKEN = "Use authentication token instead of password"
-LOGIN_PROMPT_AUTH_TOKEN = "Please enter your authentication token"
+LOGIN_HELP_AUTH_TOKEN = "Enter authentication token instead of password"
 LOGIN_ORGANIZATION_HELP = "Organization to log in to"
 LOGIN_ALREADY_LOGGED_IN = "Seems you\'re already logged in"
 LOGIN_SUCCESS = "Successfully logged in as {0}"
@@ -17,6 +16,11 @@ LOGIN_INVALID_CREDENTIALS = "Invalid credentials"
 LOGOUT_SUCCESS = "Logged out successfully"
 LOGOUT_CONFIG_MISSING = "Cannot logout. Config file is missing. Try logging in first"
 
+# ME
+ME_SUCCESS_API = "API: {0}/api/v2"
+ME_SUCCESS_LOGS = "Logs file located at: {0}"
+ME_SUCCESS = "Logged in as: {0}"
+ME_LOGGER_SUCCESS = "Successfully printed user's details (cnvrgv2 me)"
 
 # DATA OWNER
 DATA_UPLOAD_SUCCESS = "Successfully uploaded updated files"
@@ -32,7 +36,6 @@ SYNC_OUTPUT_DIR = "The directory that will be synced inside the project"
 CLONE_NUMBER_OF_THREADS = "Number of threads that will be used to preform the clone"
 QUERY_SLUG = "Query slug"
 
-
 # DATASET
 DATASET_PROMPT_CLONE = "Please enter dataset name to clone"
 DATASET_HELP_CLONE = "Name of the dataset to clone"
@@ -49,7 +52,7 @@ DATASET_CLONE_SUCCESS = "Successfully cloned dataset: {0}"
 DATASET_PUT_PROMPT_FILES = "Please enter a comma separated list of file paths to upload. use . " \
                            "to upload the whole directory"
 DATASET_PUT_HELP_FILES = "A comma separated list of file paths to upload. use . " \
-                           "to upload the whole directory"
+                         "to upload the whole directory"
 DATASET_REMOVE_PROMPT_FILES = "Please enter a comma separated list of file paths to remove. Wildcards allowed"
 DATASET_REMOVE_HELP_FILES = "A comma separated list of file paths to remove. use Wildcards allowed"
 DATASET_REMOVE_SUCCESS = "Files removed successfully"
@@ -107,7 +110,6 @@ PROJECT_CREATE_FOLDER_NOT_EMPTY = "Warning! You're about to associate a non empt
 PROJECT_CREATING_PROJECT = "Creating new project {0}"
 PROJECT_CREATE_SUCCESS = "Successfully created project {0}"
 PROJECT_SYNC_SUCCESS = "Successfully synced project {0}"
-PROJECT_DOWNLOAD_HELP_COMMIT = "Sha1 of the commit to download"
 
 # FILES
 FILES_UPLOAD_SUCCESS = "Successfully uploaded files"
@@ -128,7 +130,6 @@ MEMBER_ENTER_ROLE = "Please enter a valid role [admin, manager, member, reviewer
 MEMBER_HELP_ROLE = "A role for the user, must be one of the following: admin, manager, member, reviewer"
 MEMBER_REMOVED_SUCCESS = "{0} was removed successfully"
 
-
 # EXPERIMENT
 EXPERIMENT_PROMPT_TITLE = "Please enter a title for the experiment"
 EXPERIMENT_PROMPT_COMMIT = "Please enter commit to merge"
@@ -156,7 +157,6 @@ EXPERIMENT_LOG_IMAGES_SUCCESS = "Successfully logged images"
 EXPERIMENT_PULL_ARTIFACTS_SUCCESS = "Successfully pulled artifacts"
 EXPERIMENT_HELP_WORK_DIR = "Working Dir to upload files to"
 
-
 # LOGS
 LOG_START_COMMAND = "Starting command {0}. Options: {1}"
 LOG_CLONING_PROJECT = "Cloning project: {0}"
@@ -171,10 +171,10 @@ SSH_HELP_KUBECTL = "Full path to kubeconfig file, otherwise default will be used
 SSH_STARTING_SESSION = "Starting a new ssh session"
 SSH_WAITING_FOR_READY = "Waiting for ssh session to be ready..."
 SSH_READY = "\r\nSsh session is ready to receive connections.\r\n" \
-            "\r\nIn order to connect to your job, define your ssh connection with the following params:\r\n"\
-            "host: 127.0.0.1\r\n"\
-            "port: {0}\r\n"\
-            "username: {1}\r\n"\
+            "\r\nIn order to connect to your job, define your ssh connection with the following params:\r\n" \
+            "host: 127.0.0.1\r\n" \
+            "port: {0}\r\n" \
+            "username: {1}\r\n" \
             "password: {2}"
 
 # WORKSPACE
@@ -191,6 +191,10 @@ ENDPOINT_METRIC_NAME = "The metric name"
 ENDPOINT_METRIC_X = "The metric x value"
 ENDPOINT_METRIC_Y = "The metric y value"
 
+# FLOWS
+FLOW_YAML_PATH = "Path to yaml file, describing the new flow"
+FLOW_CREATE_SUCCESS = "Flow {0} created successfully."
+
 # CONFIG
 CONFIG_HELP_CHECK_CERTIFICATE = "{0} ssl validation on https requests"
 CONFIG_UPDATE_SUCCESS = "Config updated successfully"
@@ -230,3 +234,22 @@ REGISTRY_PROMPT_URL = "Please enter registry url"
 REGISTRY_PROMPT_TITLE = "Please enter registry tag"
 
 REGISTRY_CREATE_SUCCESS = "Successfully created registry {0}"
+
+# ORGANIZATION SETTINGS
+ORGANIZATION_SETTINGS_HELP_DEFAULT_COMPUTES = "Default computes"
+ORGANIZATION_SETTINGS_HELP_INSTALL_DEPENDENCIES = "Install dependencies"
+ORGANIZATION_SETTINGS_HELP_SLACK_WEBHOOK_URL = "Slack webhook URL"
+ORGANIZATION_SETTINGS_HELP_DEBUG_TIME = "Debug time"
+ORGANIZATION_SETTINGS_HELP_EMAIL_ON_ERROR = "Send email on error"
+ORGANIZATION_SETTINGS_HELP_EMAIL_ON_SUCCESS = "Send email on success"
+ORGANIZATION_SETTINGS_HELP_QUEUED_COMPUTE_WAIT_TIME = "Queued compute wait time"
+ORGANIZATION_SETTINGS_HELP_IDLE_ENABLED = "Enable or Disable idle time"
+ORGANIZATION_SETTINGS_HELP_IDLE_TIME = "Idle time"
+ORGANIZATION_SETTINGS_HELP_MAX_DURATION_WORKSPACES = "Max duration for workspaces"
+ORGANIZATION_SETTINGS_HELP_MAX_DURATION_EXPERIMENTS = "Max duration for experiments"
+ORGANIZATION_SETTINGS_HELP_MAX_DURATION_ENDPOINTS = "Max duration for endpoints"
+ORGANIZATION_SETTINGS_HELP_MAX_DURATION_WEBAPPS = "Max duration for webapps"
+ORGANIZATION_SETTINGS_HELP_AUTOMATICALLY_CLEAR_CACHED_COMMITS = "Number of cached commits to be cleared" \
+                                                                " automatically"
+ORGANIZATION_SETTINGS_HELP_CUSTOM_PYPI_ENABLED = "Enable custom PYPI"
+ORGANIZATION_SETTINGS_HELP_CUSTOM_PYPI_URL = "Custom PYPI URL"
