@@ -4,7 +4,7 @@ import requests
 
 from cnvrgv2.config import Config, CONFIG_VERSION
 from cnvrgv2.config import error_messages, routes
-from cnvrgv2.errors import CnvrgArgumentsError, CnvrgError, CnvrgHttpError
+from cnvrgv2.errors import CnvrgArgumentsError, CnvrgError, CnvrgHttpError, CnvrgLoginError
 from cnvrgv2.modules.users.users_client import UsersClient
 from cnvrgv2.proxy import HTTP, Proxy
 
@@ -255,7 +255,7 @@ class Context:
         """
         logged_in = self._load_from_env() or self._load_from_config()
         if not logged_in:
-            raise CnvrgError(error_messages.CONTEXT_BAD_ENV_VARIABLES)
+            raise CnvrgLoginError(error_messages.CONTEXT_BAD_ENV_VARIABLES)
 
     def _load_from_env(self):
         """
