@@ -1,20 +1,21 @@
-import os
-import time
-import threading
 import mimetypes
+import os
+import threading
+import time
+from queue import Empty, Full, Queue
 
-from queue import Queue, Empty, Full
 from cnvrgv2.cli.utils.progress_bar_utils import init_progress_bar_for_cli
-from cnvrgv2.utils.converters import convert_bytes
-from cnvrgv2.utils.storage_utils import chunk_list, get_file_sha1, total_files_size, append_trailing_slash
 from cnvrgv2.data.clients.storage_client_factory import storage_client_factory
+from cnvrgv2.utils.converters import convert_bytes
+from cnvrgv2.utils.storage_utils import append_trailing_slash, get_file_sha1
 
 
 class LocalFilesHandler:
     def __init__(
         self,
         data_owner,
-        files,
+        paths,
+        metadata,
         override=False,
         num_workers=40,
         chunk_size=1000,
@@ -24,7 +25,8 @@ class LocalFilesHandler:
         """
         Multithreaded local file handler base class
         @param data_owner: Cnvrg dataset / project object
-        @param files: List of files to handle
+        @param paths: [Generator] that lists paths to upload
+        @param metadata: [Dict] The metadata on the uploaded files (total files, file size..)
         @param override: Boolean stating whether or not we should re-upload even if the file already exists
         @param num_workers: Number of threads to use for concurrent file handling
         @param chunk_size: File meta chunk size to fetch from the server
@@ -33,19 +35,18 @@ class LocalFilesHandler:
         """
         # Init the storage client
         self.data_owner = data_owner
-        self.storage_meta = data_owner.storage_meta
-        self.storage_client = storage_client_factory(storage_meta=self.storage_meta)
+        self.storage_client = storage_client_factory(refresh_function=data_owner.storage_meta_refresh_function())
 
         # Init helper vars
         self.override = override
         self.queue_size = queue_size
         self.chunk_size = chunk_size
-        self.chunks = chunk_list(files, self.chunk_size)
+        self.path_generator = paths
         self.progress_bar_enabled = progress_bar_enabled
         self.errors = []
         self.progress_bar = None
         if progress_bar_enabled:
-            self.progress_bar = init_progress_bar_for_cli("Uploading", total_files_size(files))
+            self.progress_bar = init_progress_bar_for_cli("Uploading", metadata["total_size"])
 
         # Init file queues
         self.progress_queue = Queue(self.queue_size)
@@ -63,7 +64,7 @@ class LocalFilesHandler:
         self.collector_thread.start()
 
         # Create progress thread which tracks the upload progress
-        self.total_files = len(files)
+        self.total_files = metadata["total_files"]
         self.handled_files = 0
         self.progress_thread = threading.Thread(target=self.task_progress)
         self.progress_thread.start()
@@ -106,62 +107,87 @@ class LocalFilesHandler:
         The function that handles collecting files metadata from the server
         @return: None
         """
-        for chunk in self.chunks:
-            files_metadata = {}
-            for fullpath in chunk:
 
-                is_file = os.path.isfile(fullpath)
-                is_directory = os.path.isdir(fullpath)
+        files_chunk = {}
+        data_owner_root = append_trailing_slash(self.data_owner._config.root) if self.data_owner._config.root else ''
 
-                if is_file:
-                    content_type = mimetypes.guess_type(fullpath, strict=True)[0] or "plain/text"
-                    files_metadata[fullpath] = {
-                        "sha1": get_file_sha1(fullpath),
-                        "file_name": os.path.basename(fullpath),
-                        "file_size": os.path.getsize(fullpath),
-                        "local_path": fullpath,
-                        "content_type": content_type,
-                        "relative_path": fullpath.replace(append_trailing_slash(self.data_owner.working_dir), '')
-                    }
-                elif is_directory:
-                    # For directories we don't need any metadata
-                    files_metadata[fullpath] = None
+        for fullpath in self.path_generator:
+            # Normalize fullpath to be relative to the working directory
+            fullpath = fullpath.replace(data_owner_root, "")
 
-            try:
-                files_to_upload = self._file_collector_function(files_metadata)
-            except Exception as e:
-                self.errors.append(e)
-                if self.progress_bar_enabled:
-                    print("Could not process files {}".format(chunk))
-                    print(e)
+            is_file = os.path.isfile(fullpath)
+            is_directory = os.path.isdir(fullpath)
 
-                self.handling_active.clear()
-                return
+            if is_file:
+                content_type = mimetypes.guess_type(fullpath, strict=True)[0] or "plain/text"
+                files_chunk[fullpath] = {
+                    "sha1": get_file_sha1(fullpath),
+                    "file_name": os.path.basename(fullpath),
+                    "file_size": os.path.getsize(fullpath),
+                    "local_path": fullpath,
+                    "content_type": content_type,
+                    # TODO: Might be an unnecessary duplicate of line 116. Check and remove the replace if not needed
+                    "relative_path": fullpath.replace(append_trailing_slash(self.data_owner.working_dir), '')
+                }
+            elif is_directory:
+                # For directories we don't need any metadata
+                files_chunk[fullpath] = None
 
-            # Since we don't want to re-upload files the server might less files to upload than the chunks size
-            # In that case we add the delta to the progress since those files already exist
-            with self.progress_lock:
-                self.handled_files += len(chunk) - len(files_to_upload)
+            if len(files_chunk) % self.chunk_size == 0:
+                self._handle_collector_files(files_chunk)
+                files_chunk.clear()
 
-                # Show progress for files already in server
-                if self.progress_bar_enabled:
-                    chunk_progress = 0
-                    for file_name in chunk:
-                        if not any(file for file in files_to_upload
-                                   if file["fullpath"] == self._normalize_file_name(file_name)):
-                            file_size = files_metadata[file_name]["file_size"] if files_metadata[file_name] else 0
-                            chunk_progress += file_size
-                    converted_bytes, unit = convert_bytes(chunk_progress, self.progress_bar.unit)
-                    self.progress_bar.next(converted_bytes)
+        # Handle remaining chunk
+        self._handle_collector_files(files_chunk)
 
-            # Attempt to put the new files in the upload queue, non-blocking in case we want to stop the upload
-            for file in files_to_upload:
-                while self.handling_active.is_set():
-                    try:
-                        self.handle_queue.put_nowait(file)
-                        break
-                    except Full:
-                        time.sleep(0.5)
+    def _handle_collector_files(self, files_chunk):
+        """
+        Helper function that handles calling the server and pushes the result to the worker threads
+        @param files_chunk: Chunk of files to process
+        @return: None
+        """
+        try:
+            files_to_upload = self._file_collector_function(files_chunk)
+        except Exception as e:
+            self.errors.append(e)
+            if self.progress_bar_enabled:
+                print("Could not process files")
+                print(e)
+
+            self.handling_active.clear()
+            return
+
+        self._handle_collector_progress(files_chunk, files_to_upload)
+
+        # Attempt to put the new files in the upload queue, non-blocking in case we want to stop the upload
+        for file in files_to_upload:
+            while self.handling_active.is_set():
+                try:
+                    self.handle_queue.put_nowait(file)
+                    break
+                except Full:
+                    time.sleep(0.5)
+
+    def _handle_collector_progress(self, chunk, files_to_upload):
+        """
+        Handles upload progress in case the some of the files we were trying to upload already exist in the server and
+        do not need to be re-uploaded again.
+        @param chunk: [Dict] The file metadata we sent to the server
+        @param files_to_upload: [List] The list of files that needed to get uploaded
+        @return: None
+        """
+        with self.progress_lock:
+            self.handled_files += len(chunk) - len(files_to_upload)
+
+            # Show progress for files already in server
+            if self.progress_bar_enabled:
+                # Calculate total file size for files (minus folders) to upload:
+                chunk_file_size = sum([chunk[fullpath]["file_size"] for fullpath in chunk if chunk[fullpath]])
+                # Calculate total file size of the files needed to upload:
+                upload_file_size = sum([file["file_size"] for file in files_to_upload])
+                # Calculate the size of the file we are NOT going to upload and add them to the progress
+                converted_bytes, unit = convert_bytes(chunk_file_size - upload_file_size, self.progress_bar.unit)
+                self.progress_bar.next(converted_bytes)
 
     def _normalize_file_name(self, file_name):
         if file_name.startswith('/'):
