@@ -4,7 +4,6 @@ import os
 import re
 import shutil
 import time
-from datetime import datetime
 from itertools import chain
 
 from cnvrgv2.cli.utils.progress_bar_utils import init_progress_bar_for_cli
@@ -46,27 +45,15 @@ class DataOwner(DynamicAttributes):
         Creates a function that returns an object containing credentials for the storage client
         @return: function for getting credentials for storage client
         """
-        # Calculate minutes diff from last update. If over 5 minutes - update storage meta.
-        storage_meta_update_time = None
-        storage_meta = None
         storage_client_url = urljoin(self._route, "storage_client")
         proxy = self._proxy
 
         def refresher():
-            nonlocal storage_meta_update_time
-            nonlocal storage_meta
-            minutes_diff = 0
-
-            if storage_meta_update_time is not None:
-                minutes_diff = (datetime.now() - storage_meta_update_time).total_seconds() / 60
-
-            if storage_meta is None or minutes_diff > 5:
-                response = proxy.call_api(
-                    route=storage_client_url,
-                    http_method=HTTP.GET
-                )
-                storage_meta = response.meta["storage"]
-                storage_meta_update_time = datetime.now()
+            response = proxy.call_api(
+                route=storage_client_url,
+                http_method=HTTP.GET
+            )
+            storage_meta = response.meta["storage"]
 
             return storage_meta
 
