@@ -129,3 +129,10 @@ class Dataset(DataOwner):
             return False
         finally:
             os.chdir(cwd)
+
+    def sync(self, job_slug=None, git_diff=False, progress_bar_enabled=False, message='', output_dir=None):
+        """
+        Override sync from Datasets to remove functionality.
+        sync() is only relevant for Projects
+        """
+        raise NotImplementedError("'Dataset' object has no attribute 'sync'")
