@@ -1,12 +1,11 @@
 from cnvrgv2.config import routes
-from cnvrgv2.modules.libhub.libraries.library_versions_client import LibraryVersionsClient
-from cnvrgv2.proxy import Proxy, HTTP
 from cnvrgv2.context import Context, SCOPE
 from cnvrgv2.modules.base.dynamic_attributes import DynamicAttributes
+from cnvrgv2.modules.libhub.libraries.library_versions_client import LibraryVersionsClient
+from cnvrgv2.proxy import Proxy
 
 
 class Library(DynamicAttributes):
-
     available_attributes = {
         "public": bool,
         "name": str,
@@ -39,4 +38,4 @@ class Library(DynamicAttributes):
         self._init_clients()
 
     def _init_clients(self):
-        self.versions = LibraryVersionsClient(self)
\ No newline at end of file
+        self.versions = LibraryVersionsClient(self)
