@@ -62,13 +62,6 @@ class Experiment(WorkflowInstanceBase):
         self._type = "Experiment"
         self.slug = self.scope["experiment"]
 
-    def restart(self):
-        """
-        restarts an experiment
-        @return: The restarted experiment object
-        """
-        return super().start()
-
     def finish(self, exit_status):
         # TODO: remove after uniting finish and stop in server.
         #  Ask Leah if experiment should have finish as syntax (product wise)
