@@ -1,8 +1,11 @@
 import re
 import os
+
+import yaml
+
 from cnvrgv2.config import error_messages
 from cnvrgv2.modules.users.user import ROLES
-from cnvrgv2.errors import CnvrgArgumentsError
+from cnvrgv2.errors import CnvrgArgumentsError, CnvrgFileError
 
 
 def validate_url(url):
@@ -118,3 +121,32 @@ def validate_template_type(template_type):
 
     if template_type and template_type not in AVAILABLE_TEMPLATE_TYPES:
         raise CnvrgArgumentsError(error_messages.TEMPLATE_FAULTY_TYPE)
+
+
+def _validate_yaml_path(yaml_path):
+    """
+    Checks the correctness of a YAML file
+    @param yaml_path: Path of the yaml file
+    @return: True or False
+    """
+    if not os.path.exists(yaml_path):
+        raise CnvrgFileError(error_messages.NO_FILE)
+    try:
+        with open(yaml_path, 'r') as f:
+            yaml.safe_load(f)
+    except Exception:
+        raise CnvrgFileError(error_messages.FLOW_GET_FAULTY_YAML)
+
+
+def _validate_yaml_string(yaml_string):
+    """
+    Checks the correctness of a YAML string
+    @param yaml_string: string of the yaml
+    @return: True or False
+    """
+    if not yaml_string:
+        raise CnvrgArgumentsError(error_messages.EMPTY_ARGUMENT.format("yaml_string"))
+    try:
+        yaml.safe_load(yaml_string)
+    except Exception:
+        raise CnvrgArgumentsError(error_messages.FLOW_GET_FAULTY_YAML)
